@@ -1,8 +1,11 @@
+# frozen_string_literal: true
 ##
 # Fake response for dealing with file:/// requests
 
 class Mechanize::FileResponse
 
+  attr_reader :file_path
+
   def initialize(file_path)
     @file_path = file_path
     @uri       = nil
