@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'mechanize/test_case'
 
 class TestMechanizeForm < Mechanize::TestCase
@@ -357,7 +358,7 @@ class TestMechanizeForm < Mechanize::TestCase
     assert_equal 'ticky=1&ticky=0', submitted.parser.at('#query').text
   end
 
-  def test_submit_takes_arbirary_headers
+  def test_submit_takes_arbitrary_headers
     page = @mech.get('http://localhost:2000/form_no_action.html')
     assert form = page.forms.first
     form.action = '/http_headers'
