@@ -1,4 +1,5 @@
 # coding: utf-8
+# frozen_string_literal: true
 
 require 'mechanize/test_case'
 
@@ -27,13 +28,10 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
     realm
   end
 
-  def jruby_zlib?
+  def skip_if_jruby_zlib
     if RUBY_ENGINE == 'jruby'
-      meth = caller[0][/`(\w+)/, 1]
-      warn "#{meth}: skipped because how Zlib handles error is different in JRuby"
-      true
-    else
-      false
+      meth = caller_locations(1,1).first.base_label
+      skip "#{meth}: skipped because how Zlib handles error is different in JRuby"
     end
   end
 
@@ -823,7 +821,11 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
     @res.instance_variable_set(:@header,
                                'www-authenticate' => ['Negotiate, NTLM'])
 
-    page = @agent.response_authenticate @res, nil, @uri, @req, {}, nil, nil
+    begin
+      page = @agent.response_authenticate @res, nil, @uri, @req, {}, nil, nil
+    rescue OpenSSL::Digest::DigestError
+      skip "It looks like OpenSSL is not configured to support MD4"
+    end
 
     assert_equal 'ok', page.body # lame test
   end
@@ -931,7 +933,7 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
     body_io = StringIO.new \
       "\037\213\b\0002\002\225M\000\003+H,*\001"
 
-    skip if jruby_zlib?
+    skip_if_jruby_zlib
 
     e = assert_raises Mechanize::Error do
       @agent.response_content_encoding @res, body_io
@@ -965,7 +967,8 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
 
     assert_match %r%invalid compressed data -- crc error%, log.string
   rescue IOError
-    raise unless jruby_zlib?
+    skip_if_jruby_zlib
+    raise
   end
 
   def test_response_content_encoding_gzip_checksum_corrupt_length
@@ -983,7 +986,8 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
 
     assert_match %r%invalid compressed data -- length error%, log.string
   rescue IOError
-    raise unless jruby_zlib?
+    skip_if_jruby_zlib
+    raise
   end
 
   def test_response_content_encoding_gzip_checksum_truncated
@@ -1001,7 +1005,8 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
 
     assert_match %r%unable to gunzip response: footer is not found%, log.string
   rescue IOError
-    raise unless jruby_zlib?
+    skip_if_jruby_zlib
+    raise
   end
 
   def test_response_content_encoding_gzip_empty
@@ -1023,7 +1028,7 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
 
     body = @agent.response_content_encoding @res, body_io
 
-    expected = "test\xB2"
+    expected = +"test\xB2"
     expected.force_encoding Encoding::BINARY if have_encoding?
 
     content = body.read
@@ -1042,7 +1047,8 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
 
     assert body_io.closed?
   rescue IOError
-    raise unless jruby_zlib?
+    skip_if_jruby_zlib
+    raise
   end
 
   def test_response_content_encoding_none
@@ -1304,8 +1310,13 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
     page = @agent.response_parse @res, body, @uri
 
     assert_instance_of Mechanize::Page, page
-    assert_equal 'UTF8', page.encoding
-    assert_equal 'UTF8', page.parser.encoding
+
+    # as of libxml 2.12.0, the result is dependent on how libiconv is built (which aliases are supported)
+    # if the alias "UTF8" is defined, then the result will be "UTF-8".
+    # if the alias "UTF8" is not defined, then the result will be "UTF8".
+    # note that this alias may be defined by Nokogiri itself in its EncodingHandler class.
+    assert_includes ["UTF8", "UTF-8"], page.encoding
+    assert_includes ["UTF8", "UTF-8"], page.parser.encoding
   end
 
   def test_response_parse_content_type_encoding_garbage
@@ -1422,11 +1433,11 @@ class TestMechanizeHttpAgent < Mechanize::TestCase
 
       io = @agent.response_read res, req, uri
 
-      expected = "π\n".force_encoding(Encoding::BINARY)
+      expected = "π\n".dup.force_encoding(Encoding::BINARY)
 
       # Ruby 1.8.7 doesn't let us set the write mode of the tempfile to binary,
       # so we should expect an inserted carriage return on some platforms
-      expected_with_carriage_return = "π\r\n".force_encoding(Encoding::BINARY)
+      expected_with_carriage_return = "π\r\n".dup.force_encoding(Encoding::BINARY)
 
       body = io.read
       assert_match(/^(#{expected}|#{expected_with_carriage_return})$/m, body)
