@@ -1,7 +1,10 @@
 # coding: utf-8
+# frozen_string_literal: true
 
 require 'mechanize/test_case'
 
+puts "Nokogiri::VERSION_INFO: #{Nokogiri::VERSION_INFO}"
+
 class TestMechanizePageLink < Mechanize::TestCase
 
   WINDOWS_1255 = <<-HTML
@@ -9,7 +12,7 @@ class TestMechanizePageLink < Mechanize::TestCase
 <title>hi</title>
   HTML
 
-  BAD = <<-HTML
+  BAD = <<-HTML.dup
 <meta http-equiv="content-type" content="text/html; charset=windows-1255">
 <title>Bia\xB3ystok</title>
   HTML
@@ -17,18 +20,16 @@ class TestMechanizePageLink < Mechanize::TestCase
 
   SJIS_TITLE = "\x83\x65\x83\x58\x83\x67"
 
-  SJIS_AFTER_TITLE = <<-HTML
+  SJIS_AFTER_TITLE = <<-HTML.dup
 <title>#{SJIS_TITLE}</title>
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
   HTML
-
   SJIS_AFTER_TITLE.force_encoding Encoding::BINARY if defined? Encoding
 
-  SJIS_BAD_AFTER_TITLE = <<-HTML
+  SJIS_BAD_AFTER_TITLE = <<-HTML.dup
 <title>#{SJIS_TITLE}</title>
 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
   HTML
-
   SJIS_BAD_AFTER_TITLE.force_encoding Encoding::BINARY if defined? Encoding
 
   UTF8_TITLE = 'テスト'
@@ -44,20 +45,17 @@ class TestMechanizePageLink < Mechanize::TestCase
 
     @uri = URI('http://example')
     @res = { 'content-type' => 'text/html' }
-    @body = '<title>hi</title>'
+    @body = +'<title>hi</title>'
   end
 
   def util_page body = @body, res = @res
     Mechanize::Page.new @uri, res, body && body.force_encoding(Encoding::BINARY), 200, @mech
   end
 
-  def nkf_dependency?
-    if RUBY_ENGINE == 'ruby'
-      false
-    else
-      meth = caller[0][/`(\w+)/, 1]
-      warn "#{meth}: skipped because this feature currently depends on NKF"
-      true
+  def skip_if_nkf_dependency
+    if RUBY_ENGINE == 'jruby'
+      meth = caller_locations(1,1).first.base_label
+      skip "#{meth}: skipped because this feature currently depends on NKF"
     end
   end
 
@@ -76,7 +74,7 @@ class TestMechanizePageLink < Mechanize::TestCase
   end
 
   def test_canonical_uri_unescaped
-    page = util_page <<-BODY
+    page = util_page(+<<-BODY)
 <head>
   <link rel="canonical" href="http://example/white space"/>
 </head>
@@ -98,7 +96,7 @@ class TestMechanizePageLink < Mechanize::TestCase
   end
 
   def test_encoding
-    page = util_page WINDOWS_1255
+    page = util_page WINDOWS_1255.dup
 
     assert_equal 'windows-1255', page.encoding
   end
@@ -112,17 +110,20 @@ class TestMechanizePageLink < Mechanize::TestCase
   end
 
   def test_encoding_charset_after_title_bad
-    return if nkf_dependency?
+    skip_if_nkf_dependency
 
-    page = util_page UTF8
+    # https://gitlab.gnome.org/GNOME/libxml2/-/issues/543
+    skip if Nokogiri.uses_libxml?([">= 2.11.0", "< 2.12.0"])
+
+    page = util_page UTF8.dup
 
     assert_equal false, page.encoding_error?
 
-    assert_equal 'UTF-8', page.encoding
+    assert_equal "UTF-8", page.encoding
   end
 
   def test_encoding_charset_after_title_double_bad
-    return if nkf_dependency?
+    skip_if_nkf_dependency
 
     page = util_page SJIS_BAD_AFTER_TITLE
 
@@ -132,9 +133,12 @@ class TestMechanizePageLink < Mechanize::TestCase
   end
 
   def test_encoding_charset_bad
-    return if nkf_dependency?
+    skip_if_nkf_dependency
 
-    page = util_page "<title>#{UTF8_TITLE}</title>"
+    # https://gitlab.gnome.org/GNOME/libxml2/-/issues/543
+    skip if Nokogiri.uses_libxml?([">= 2.11.0", "< 2.12.0"])
+
+    page = util_page(+"<title>#{UTF8_TITLE}</title>")
     page.encodings.replace %w[
       UTF-8
       Shift_JIS
@@ -146,7 +150,7 @@ class TestMechanizePageLink < Mechanize::TestCase
   end
 
   def test_encoding_meta_charset
-    page = util_page "<meta charset='UTF-8'>"
+    page = util_page(+"<meta charset='UTF-8'>")
 
     assert_equal 'UTF-8', page.encoding
   end
@@ -337,7 +341,7 @@ class TestMechanizePageLink < Mechanize::TestCase
   end
 
   def test_title_none
-    page = util_page '' # invalid HTML
+    page = util_page(+'') # invalid HTML
 
     assert_nil(page.title)
   end
